@@ -17,7 +17,7 @@ use warnings;
 
 {
     package Doit;
-    our $VERSION = '0.024';
+    our $VERSION = '0.025';
 
     use constant IS_WIN => $^O eq 'MSWin32';
 }
@@ -338,13 +338,19 @@ use warnings;
     sub _new {
 	my $class = shift;
 	my $self = bless { }, $class;
-	# XXX hmmm, creating now self-refential data structures ...
-	$self->{runner}    = Doit::Runner->new($self);
-	$self->{dryrunner} = Doit::Runner->new($self, 1);
 	$self;
     }
-    sub runner    { shift->{runner} }
-    sub dryrunner { shift->{dryrunner} }
+    sub runner {
+	my($self) = @_;
+	# XXX hmmm, creating now self-refential data structures ...
+	$self->{runner} ||= Doit::Runner->new($self);
+    }
+	    
+    sub dryrunner {
+	my($self) = @_;
+	# XXX hmmm, creating now self-refential data structures ...
+	$self->{dryrunner} ||= Doit::Runner->new($self, dryrun => 1);
+    }
 
     sub init {
 	my($class) = @_;
@@ -1524,8 +1530,10 @@ use warnings;
 {
     package Doit::Runner;
     sub new {
-	my($class, $X, $dryrun) = @_;
-	bless { X => $X, dryrun => $dryrun, components => [] }, $class;
+	my($class, $Doit, %options) = @_;
+	my $dryrun = delete $options{dryrun};
+	die "Unhandled options: " . join(" ", %options) if %options;
+	bless { Doit => $Doit, dryrun => $dryrun, components => [] }, $class;
     }
     sub is_dry_run { shift->{dryrun} }
 
@@ -1533,19 +1541,20 @@ use warnings;
 
     sub install_generic_cmd {
 	my($self, $name, @args) = @_;
-	$self->{X}->install_generic_cmd($name, @args);
-	install_cmd($name); # XXX hmmmm
+	$self->{Doit}->install_generic_cmd($name, @args);
+	__PACKAGE__->install_cmd($name);
     }
 
-    sub install_cmd ($) {
+    sub install_cmd {
+	shift; # $class unused
 	my $cmd = shift;
 	my $meth = 'cmd_' . $cmd;
 	my $code = sub {
 	    my($self, @args) = @_;
 	    if ($self->{dryrun}) {
-		$self->{X}->$meth(@args)->show;
+		$self->{Doit}->$meth(@args)->show;
 	    } else {
-		$self->{X}->$meth(@args)->doit;
+		$self->{Doit}->$meth(@args)->doit;
 	    }
 	};
 	no strict 'refs';
@@ -1553,17 +1562,23 @@ use warnings;
     }
 
     sub add_component {
-	my($self, $component) = @_;
+	my($self, $component_or_module) = @_;
+	my $module;
+	if ($component_or_module =~ /::/) {
+	    $module = $component_or_module;
+	} else {
+	    $module = 'Doit::' . ucfirst($component_or_module);
+	}
+
 	for (@{ $self->{components} }) {
-	    return if $_->{component} eq $component;
+	    return if $_->{module} eq $module;
 	}
 
-	my $module = 'Doit::' . ucfirst($component);
 	if (!eval qq{ require $module; 1 }) {
-	    die "Cannot load $module: $@";
+	    Doit::Log::error("Cannot load $module: $@");
 	}
 	my $o = $module->new
-	    or die "Error while calling $module->new";
+	    or Doit::Log::error("Error while calling $module->new");
 	for my $function ($o->functions) {
 	    my $fullqual = $module.'::'.$function;
 	    my $code = sub {
@@ -1577,7 +1592,7 @@ use warnings;
 	    (my $relpath = $module) =~ s{::}{/};
 	    $relpath .= '.pm';
 	};
-	push @{ $self->{components} }, { component => $component, module => $module, path => $INC{$mod_file}, relpath => $mod_file };
+	push @{ $self->{components} }, { module => $module, path => $INC{$mod_file}, relpath => $mod_file };
 
 	if ($o->can('add_components')) {
 	    for my $sub_component ($o->add_components) {
@@ -1602,7 +1617,7 @@ use warnings;
 		 qw(change_file), # own invention
 		 qw(setenv unsetenv), # $ENV manipulation
 		) {
-	install_cmd $cmd;
+	__PACKAGE__->install_cmd($cmd);
     }
 
     sub call_wrapped_method {
@@ -1662,6 +1677,8 @@ use warnings;
 	die "Please use either Doit::RPC::Client, Doit::RPC::Server or Doit::RPC::SimpleServer";
     }
 
+    sub runner { shift->{runner} }
+
     sub receive_data {
 	my($self) = @_;
 	my $fh = $self->{infh};
@@ -1845,7 +1862,7 @@ use warnings;
 		return;
 	    }
 	    $d->(" calling method $data[0]");
-	    my($rettype, @ret) = $self->{runner}->call_wrapped_method($context, @data);
+	    my($rettype, @ret) = $self->runner->call_wrapped_method($context, @data);
 	    $d->(" sending result back");
 	    $self->send_data($rettype, @ret);
 	}
@@ -1889,7 +1906,7 @@ use warnings;
 	    } else {
 		open STDOUT, '>', "/dev/stderr" or die $!; # XXX????
 	    }
-	    my($rettype, @ret) = $self->{runner}->call_wrapped_method($context, @data);
+	    my($rettype, @ret) = $self->runner->call_wrapped_method($context, @data);
 	    open STDOUT, ">&", $oldout or die $!;
 	    $self->send_data($rettype, @ret);
 	}
@@ -1917,7 +1934,7 @@ use warnings;
 
     sub add_components {
 	my(@components) = @_;
-	q|for my $component (qw(| . join(" ", map { qq{$_->{component}} } @components) . q|)) { $d->add_component($component) } |;
+	q|for my $component_module (qw(| . join(" ", map { qq{$_->{module}} } @components) . q|)) { $d->add_component($component_module) } |;
     }
 
     sub self_require (;$) {
